@@ -185,6 +185,10 @@ class MultiLabelClassificationModel(ClassificationModel):
 
         self.tokenizer = tokenizer_class.from_pretrained(model_name, do_lower_case=self.args.do_lower_case, **kwargs)
 
+        if self.args.special_tokens_list:
+            self.tokenizer.add_tokens(self.args.special_tokens_list, special_tokens=True)
+            self.model.resize_token_embeddings(len(self.tokenizer))
+
         self.args.model_name = model_name
         self.args.model_type = model_type
 
