@@ -61,7 +61,7 @@ class ModelArgs:
     max_seq_length: int = 128
     model_name: str = None
     model_type: str = None
-    multiprocessing_chunksize: int = 500
+    multiprocessing_chunksize: int = -1
     n_gpu: int = 1
     no_cache: bool = False
     no_save: bool = False
