@@ -8,32 +8,34 @@ from transformers import (
     ElectraForMaskedLM,
     ElectraForPreTraining,
     FlaubertModel,
+    LongformerModel,
     RobertaModel,
     XLMModel,
     XLMPreTrainedModel,
     XLNetModel,
     XLNetPreTrainedModel,
 )
-from transformers.configuration_camembert import CamembertConfig
-from transformers.configuration_distilbert import DistilBertConfig
-from transformers.configuration_roberta import RobertaConfig
-from transformers.configuration_xlm_roberta import XLMRobertaConfig
-from transformers.modeling_albert import AlbertConfig, AlbertModel, AlbertPreTrainedModel
-from transformers.modeling_distilbert import DISTILBERT_PRETRAINED_MODEL_ARCHIVE_LIST
-from transformers.modeling_electra import (
+from transformers.models.camembert.configuration_camembert import CamembertConfig
+from transformers.models.distilbert.configuration_distilbert import DistilBertConfig
+from transformers.models.roberta.configuration_roberta import RobertaConfig
+from transformers.models.xlm_roberta.configuration_xlm_roberta import XLMRobertaConfig
+from transformers.models.albert.modeling_albert import AlbertConfig, AlbertModel, AlbertPreTrainedModel
+from transformers.models.distilbert.modeling_distilbert import DISTILBERT_PRETRAINED_MODEL_ARCHIVE_LIST
+from transformers.models.electra.modeling_electra import (
     ELECTRA_PRETRAINED_MODEL_ARCHIVE_LIST,
     ElectraConfig,
     ElectraModel,
     ElectraPreTrainedModel,
 )
-from transformers.modeling_camembert import CAMEMBERT_PRETRAINED_MODEL_ARCHIVE_LIST
-from transformers.modeling_roberta import (
+from transformers.models.camembert.modeling_camembert import CAMEMBERT_PRETRAINED_MODEL_ARCHIVE_LIST
+from transformers.models.roberta.modeling_roberta import (
     ROBERTA_PRETRAINED_MODEL_ARCHIVE_LIST,
     RobertaClassificationHead,
     RobertaForQuestionAnswering,
 )
 from transformers.modeling_utils import PreTrainedModel, SequenceSummary
-from transformers.modeling_xlm_roberta import XLM_ROBERTA_PRETRAINED_MODEL_ARCHIVE_LIST
+from transformers.models.xlm_roberta.modeling_xlm_roberta import XLM_ROBERTA_PRETRAINED_MODEL_ARCHIVE_LIST
+from transformers.models.longformer.modeling_longformer import LongformerClassificationHead, LongformerPreTrainedModel
 
 
 class BertForMultiLabelSequenceClassification(BertPreTrainedModel):
@@ -125,6 +127,16 @@ class RobertaForMultiLabelSequenceClassification(BertPreTrainedModel):
         return outputs
 
 
+class BertweetForMultiLabelSequenceClassification(RobertaForMultiLabelSequenceClassification):
+    """
+    BERTweet model adapted for multi-label sequence classification.
+    BERTweet shares the Roberta architecture, so we can reuse the simpletransformers
+    RobertaForMultiLabelSequenceClassification implementation
+    """
+
+    base_model_prefix = "bertweet"
+
+
 class CamembertForMultiLabelSequenceClassification(RobertaForMultiLabelSequenceClassification):
     """
     Camembert model adapted for multi-label sequence classification.
@@ -416,6 +428,56 @@ class FlaubertForMultiLabelSequenceClassification(FlaubertModel):
         return outputs
 
 
+class LongformerForMultiLabelSequenceClassification(LongformerPreTrainedModel):
+    """
+    Longformer model adapted for multilabel sequence classification.
+    """
+
+    def __init__(self, config, pos_weight=None):
+        super(LongformerForMultiLabelSequenceClassification, self).__init__(config)
+        self.num_labels = config.num_labels
+        self.pos_weight = pos_weight
+
+        self.longformer = LongformerModel(config)
+        self.classifier = LongformerClassificationHead(config)
+
+        self.init_weights()
+
+    def forward(
+        self,
+        input_ids=None,
+        attention_mask=None,
+        global_attention_mask=None,
+        token_type_ids=None,
+        position_ids=None,
+        inputs_embeds=None,
+        labels=None,
+    ):
+        if global_attention_mask is None:
+            global_attention_mask = torch.zeros_like(input_ids)
+            # global attention on cls token
+            global_attention_mask[:, 0] = 1
+
+        outputs = self.longformer(
+            input_ids,
+            attention_mask=attention_mask,
+            global_attention_mask=global_attention_mask,
+            token_type_ids=token_type_ids,
+            position_ids=position_ids,
+        )
+        sequence_output = outputs[0]
+        logits = self.classifier(sequence_output)
+
+        outputs = (logits,) + outputs[2:]
+        if labels is not None:
+            loss_fct = BCEWithLogitsLoss(pos_weight=self.pos_weight)
+            labels = labels.float()
+            loss = loss_fct(logits.view(-1, self.num_labels), labels.view(-1, self.num_labels))
+            outputs = (loss,) + outputs
+
+        return outputs
+
+
 class XLMRobertaForMultiLabelSequenceClassification(RobertaForMultiLabelSequenceClassification):
     config_class = XLMRobertaConfig
     pretrained_model_archive_map = XLM_ROBERTA_PRETRAINED_MODEL_ARCHIVE_LIST
@@ -456,12 +518,12 @@ class ElectraForLanguageModelingModel(PreTrainedModel):
     def tie_generator_and_discriminator_embeddings(self):
         self.discriminator_model.set_input_embeddings(self.generator_model.get_input_embeddings())
 
-    def forward(self, inputs, masked_lm_labels, attention_mask=None, token_type_ids=None):
+    def forward(self, inputs, labels, attention_mask=None, token_type_ids=None):
         d_inputs = inputs.clone()
 
         # run masked LM.
         g_out = self.generator_model(
-            inputs, masked_lm_labels=masked_lm_labels, attention_mask=attention_mask, token_type_ids=token_type_ids
+            inputs, labels=labels, attention_mask=attention_mask, token_type_ids=token_type_ids
         )
 
         # get samples from masked LM.
@@ -472,14 +534,14 @@ class ElectraForLanguageModelingModel(PreTrainedModel):
         sampled_tokens = sampled_tokens.view(d_inputs.shape[0], -1)
 
         # labels have a -100 value to mask out loss from unchanged tokens.
-        mask = masked_lm_labels.ne(-100)
+        mask = labels.ne(-100)
 
         # replace the masked out tokens of the input with the generator predictions.
         d_inputs[mask] = sampled_tokens[mask]
 
         # turn mask into new target labels.  1 (True) for corrupted, 0 otherwise.
         # if the prediction was correct, mark it as uncorrupted.
-        correct_preds = sampled_tokens == masked_lm_labels
+        correct_preds = sampled_tokens == labels
         d_labels = mask.long()
         d_labels[correct_preds] = 0
 
