@@ -33,7 +33,6 @@ from transformers.optimization import (
 )
 from transformers.optimization import AdamW, Adafactor
 from transformers import (
-    WEIGHTS_NAME,
     AlbertConfig,
     AlbertForQuestionAnswering,
     AlbertTokenizer,
@@ -46,6 +45,9 @@ from transformers import (
     BertConfig,
     BertForQuestionAnswering,
     BertTokenizer,
+    CamembertConfig,
+    CamembertForQuestionAnswering,
+    CamembertTokenizer,
     DistilBertConfig,
     DistilBertForQuestionAnswering,
     DistilBertTokenizer,
@@ -54,12 +56,19 @@ from transformers import (
     LongformerConfig,
     LongformerForQuestionAnswering,
     LongformerTokenizer,
+    MPNetConfig,
+    MPNetForQuestionAnswering,
+    MPNetTokenizer,
     MobileBertConfig,
     MobileBertForQuestionAnswering,
     MobileBertTokenizer,
     RobertaConfig,
     RobertaForQuestionAnswering,
     RobertaTokenizer,
+    SqueezeBertConfig,
+    SqueezeBertForQuestionAnswering,
+    SqueezeBertTokenizer,
+    WEIGHTS_NAME,
     XLMConfig,
     XLMForQuestionAnswering,
     XLMRobertaConfig,
@@ -120,11 +129,14 @@ class QuestionAnsweringModel:
             "auto": (AutoConfig, AutoTokenizer, AutoModelForQuestionAnswering),
             "bart": (BartConfig, BartForQuestionAnswering, BartTokenizer),
             "bert": (BertConfig, BertForQuestionAnswering, BertTokenizer),
+            "camembert": (CamembertConfig, CamembertForQuestionAnswering, CamembertTokenizer),
             "distilbert": (DistilBertConfig, DistilBertForQuestionAnswering, DistilBertTokenizer),
             "electra": (ElectraConfig, ElectraForQuestionAnswering, ElectraTokenizer),
             "longformer": (LongformerConfig, LongformerForQuestionAnswering, LongformerTokenizer),
             "mobilebert": (MobileBertConfig, MobileBertForQuestionAnswering, MobileBertTokenizer),
+            "mpnet": (MPNetConfig, MPNetForQuestionAnswering, MPNetTokenizer),
             "roberta": (RobertaConfig, RobertaForQuestionAnswering, RobertaTokenizer),
+            "squeezebert": (SqueezeBertConfig, SqueezeBertForQuestionAnswering, SqueezeBertTokenizer),
             "xlm": (XLMConfig, XLMForQuestionAnswering, XLMTokenizer),
             "xlmroberta": (XLMRobertaConfig, XLMRobertaForQuestionAnswering, XLMRobertaTokenizer),
             "xlnet": (XLNetConfig, XLNetForQuestionAnswering, XLNetTokenizer),
@@ -192,7 +204,16 @@ class QuestionAnsweringModel:
             except AttributeError:
                 raise AttributeError("fp16 requires Pytorch >= 1.6. Please update Pytorch or turn off fp16.")
 
-        self.tokenizer = tokenizer_class.from_pretrained(model_name, do_lower_case=self.args.do_lower_case, **kwargs)
+        if model_type == "auto":
+            self.tokenizer = tokenizer_class.from_pretrained(model_name, **kwargs)
+        else:
+            self.tokenizer = tokenizer_class.from_pretrained(
+                model_name, do_lower_case=self.args.do_lower_case, **kwargs
+            )
+
+        if self.args.special_tokens_list:
+            self.tokenizer.add_tokens(self.args.special_tokens_list, special_tokens=True)
+            self.model.resize_token_embeddings(len(self.tokenizer))
 
         self.args.model_name = model_name
         self.args.model_type = model_type
@@ -229,6 +250,38 @@ class QuestionAnsweringModel:
         ):
             features = torch.load(cached_features_file)
             logger.info(f" Features loaded from cache at {cached_features_file}")
+
+            # Convert to Tensors and build dataset
+            all_input_ids = torch.tensor([f.input_ids for f in features], dtype=torch.long)
+            all_attention_masks = torch.tensor([f.attention_mask for f in features], dtype=torch.long)
+            all_token_type_ids = torch.tensor([f.token_type_ids for f in features], dtype=torch.long)
+            all_cls_index = torch.tensor([f.cls_index for f in features], dtype=torch.long)
+            all_p_mask = torch.tensor([f.p_mask for f in features], dtype=torch.float)
+            all_is_impossible = torch.tensor([f.is_impossible for f in features], dtype=torch.float)
+
+            if mode == "dev":
+                all_feature_index = torch.arange(all_input_ids.size(0), dtype=torch.long)
+                dataset = TensorDataset(
+                    all_input_ids,
+                    all_attention_masks,
+                    all_token_type_ids,
+                    all_feature_index,
+                    all_cls_index,
+                    all_p_mask,
+                )
+            else:
+                all_start_positions = torch.tensor([f.start_position for f in features], dtype=torch.long)
+                all_end_positions = torch.tensor([f.end_position for f in features], dtype=torch.long)
+                dataset = TensorDataset(
+                    all_input_ids,
+                    all_attention_masks,
+                    all_token_type_ids,
+                    all_start_positions,
+                    all_end_positions,
+                    all_cls_index,
+                    all_p_mask,
+                    all_is_impossible,
+                )
         else:
             logger.info(" Converting to features started.")
 
@@ -674,6 +727,7 @@ class QuestionAnsweringModel:
                                             if not self.args.evaluate_during_training
                                             else training_progress_scores,
                                         )
+                        model.train()
 
             epoch_number += 1
             output_dir_current = os.path.join(output_dir, "checkpoint-{}-epoch-{}".format(global_step, epoch_number))
